function sfg = addoperand(sfg, operandname, number, innodes, outnodes, operanddata, operandtype);
% This function is used to add an operand to a signal flow graph
% 
% Inputs: sfg - signal flow graph
%         operandname - operand name as a string
%         number - operand ID number
%         innodes - operand innodes in a row vector
%                   (can be the outnode in case of an IN operand)
%         outnodes - operand outnodes in a row vector
%         operanddata - operand data in a row vector
%         operandtype - operand type as a string
% Output: sfg - updated signal flow graph


if nargin < 4
   error('Not enough input arguments');
end
if nargin < 5
   outnodes = [];
end
if nargin < 6
   operanddata = [];
end
if nargin > 7
   error('Too many input arguments');
end

% Load operand mapping
operandmapping;
s = operandstructure;

type = 0;
op = getidfromname(operandname, s);
shift_op = getidfromname('shift', s);
quant_op = getidfromname('quant', s);
overflow_op = getidfromname('overflow', s);
addsub_op = getidfromname('addsub', s);
numarg = s(op).numarg;

switch op
   case shift_op
      switch lower(operandtype)
         case 'left', type = shift_left;
         case 'right', type = shift_right;
         otherwise, error('Unknown shift type');
      end
   case quant_op
      switch lower(operandtype)
         case {'truncation', 'trunc'}, type = quant_truncation;
         case {'rounding', 'round'}, type = quant_rounding;
         case {'magnitudetruncation', 'magtrunc'}, type = quant_magnitudetruncation;
         otherwise, error('Unknown quantization type');
      end
   case overflow_op
      switch lower(operandtype)
         case 'twosc', type = overflow_twosc;
         case {'saturation', 'sat'}, type = overflow_saturation;
         otherwise, error('Unknown overflow type');
      end
   case addsub_op
      switch lower(operandtype)
         case 'add', type = addsub_add;
         case 'sub', type = addsub_sub;
         otherwise, error('Unknown overflow type');
      end
end

if s(op).isadaptor
   switch lower(operandtype)
      case {'series', 'ser'}, type = adaptor_ser;
      case {'parallel', 'par'}, type = adaptor_par;
      case {'symmetric', 'sym'}, type = adaptor_sym;
      otherwise, error('Unknown adaptor type');
   end
end

op_arg = [number, innodes, outnodes, operanddata];

if length(op_arg) ~= numarg
   error('Not correct number of operand arguments');
end

if type
   op_arg = [op_arg, type];
end

sfg = addrow(sfg, [op, op_arg]);
