function newsfg = addoperand2(sfg, operandname, op_arg, type_str);
% This function adds an operand to a signal flow graph
% 
% Inputs: sfg - signal flow graph
%         operandname - operand name as a string
%         op_arg - operand arguments
%         type_str - operand type
% Output: newsfg - signal flow graph

if nargin < 3
   error('Not enough input arguments');
end
if nargin > 4
   error('Too many input arguments');
end

% Load operand mapping
% Load operand mapping
operandmapping;
s = operandstructure;

type = 0;
op = getidfromname(operandname, s);
shift_op = getidfromname('shift', s);
quant_op = getidfromname('quant', s);
overflow_op = getidfromname('overflow', s);
numarg = s(op).numarg;

switch op
case shift_op,
   switch lower(type_str)
       case 'left', type = shift_left;
       case 'right', type = shift_right;
       otherwise, error('Unknown shift type');
   end
case quant_op,
   switch lower(type_str)
        case {'truncation', 'trunc'}, type = quant_truncation;
        case {'rounding', 'round'}, type = quant_rounding;
        case {'magnitudetruncation', 'magtrunc'}, type = quant_magnitudetruncation;
        otherwise, error('Unknown quantization type');
    end
case overflow_op,
   switch lower(type_str)
        case 'twosc', type = overflow_twosc;
        case {'saturation', 'sat'}, type = overflow_saturation;
        otherwise, error('Unknown overflow type');
    end
end

if s(op).isadaptor
    switch lower(type_str)
        case {'series', 'ser'}, type = adaptor_ser;
        case {'parallel', 'par'}, type = adaptor_par;
        case {'symmetric', 'sym'}, type = adaptor_sym;
        otherwise, error('Unknown adaptor type');
    end
end

if length(op_arg) ~= numarg
   error('Not correct number of operand arguments');
end

if type
    op_arg = [op_arg, type];
end

newsfg = addrow(sfg, [op, op_arg]);
