function sfg = cascadesfg(sfg1, sfg2)
% The output of sfg1 is connected with the input of sfg2

% Check input arguments
if nargin ~= 2
    error('Not correct number of input arguments');
end

% Load operand mapping
s = operandstructure;

% Chech sfg:s
errorlist1 = checknodes(sfg1, 1, s);
if ~isempty(errorlist1)
    error('The first signal flow graph is not correct!');
end
errorlist2 = checknodes(sfg1, 1, s);
if ~isempty(errorlist2)
    error('The second signal flow graph is not correct!');
end


out_op = getidfromname('out',s);
in_op = getidfromname('in',s);

% Check output of sfg1 and input of sfg2
outputs1 = sort(find(sfg1(:, 1) == out_op));
inputs2 = sort(find(sfg2(:, 1) == in_op));
if length(outputs1) ~= length(inputs2)
    error('The first signal flow graph not the same number outputs as the second signal flow graph has inputs!');
end

if length(outputs1) > 1
    disp('Connecting more than one input/output in ascending order based on operand id')
end

% Change all nodes in sfg2 that occur in sfg1
[innodes1, outnodes1] = getinoutnodes(sfg1);
nodes1 = sort([innodes1, outnodes1]);
nodes1(find(~diff(nodes1))) = [];
[innodes2, outnodes2] = getinoutnodes(sfg2);
nodes2 = sort([innodes2, outnodes2]);
nodes2(find(~diff(nodes2))) = [];
% numofnewnodes = 0;
% oldnodes = [];
% for i = 1:length(nodes2)
%    if length(find(nodes2(i) == nodes1))
%       oldnodes = [oldnodes, nodes2(i)];
%       numofnewnodes = numofnewnodes + 1;
%    end
% end

numofnewnodes = length(nodes2);
oldnodes = nodes2;

% Get new nodes
newnodes = getfreenode(sfg1, numofnewnodes);

% Replace the old inputs of sfg2 with the outputs of sfg1
for k = 1:length(inputs2)
    currentinput = inputs2(k);
    currentoutput = outputs1(k);
    if ~isempty(find(sfg2(currentinput,  3) == oldnodes))
        newnodes(find(sfg2(currentinput,  3) == oldnodes)) = sfg1(currentoutput, 3);
    else
        oldnodes = [oldnodes, sfg2(currentinput,  3)];
        newnodes = [newnodes, sfg1(currentoutput, 3)];
    end
end
% Update nodes in sfg2
for row = 1:size(sfg2, 1)
    [innodes_op, outnodes_op] = getinoutnodes_op(sfg2(row, :));
    nodes_op = [innodes_op, outnodes_op];
    for i = 1:length(nodes_op)
        id = find(nodes_op(i) == oldnodes);
        if ~isempty(id)
            nodes_op(i) = newnodes(id);
        end
    end
    sfg2(row, 3:2 + length(nodes_op)) = nodes_op;
end

% Remove the old the output of sfg1 and input of sfg2
for currentoutput = fliplr(outputs1')
    sfg1 = removeoperand(sfg1, 'out', sfg1(currentoutput, 2));
end
for currentinput = fliplr(inputs2')
    sfg2 = removeoperand(sfg2, 'in',  sfg2(currentinput,  2));
end

% Update operand id:s in sfg2
op_max = max(sfg2(:, 1));
for op = 1:op_max
    rows2 = find(op == sfg2(:, 1));
    if ~isempty(rows2)
        rows1 = find(op == sfg1(:, 1));
        if ~isempty(rows1)
            minid = max(sfg1(rows1, 2)) + 1;
        else
            minid = 1;
        end
        sfg2(rows2, 2) = (minid:minid + length(rows2) - 1)';
    end
end

% Concatenate the two sfg:s
col1 = size(sfg1, 2);
col2 = size(sfg2, 2);
if col1 < col2
    sfg1 = [sfg1, NaN*ones(size(sfg1, 1), col2 - col1)];
elseif col2 < col1
    sfg2 = [sfg2, NaN*ones(size(sfg2, 1), col1 - col2)];
end
sfg = [sfg1; sfg2];

