function[newschedule]=changestarttime(schedule,operandname,number,timedifference)
% % Changes the starttime as starttime = startime + timedifference;

if(nargin > 4)
    error('Too many inputs')
end
if(nargin < 4)
    error('Too few inputs')
end

% uncomment for debug only!
%   schedule=sch2;
%   operandname='out';
%   number = 2;
%   timedifference = 2;
%-------------------------------------------------
% Extract SFG CFG -> timing info
%-------------------------------------------------
size_schedule=size(schedule);
scheduletime=schedule(1,1);
nlcount=schedule(1,2);

s = operandstructure;

cfg=schedule(2:size_schedule(1),1:size_schedule(2));
sfg=schedule(2:size_schedule(1),1:size_schedule(2)-3-nlcount);

%time info computation
time_columns_index=size_schedule(2)-2-nlcount;
timecol = [time_columns_index:size_schedule(2)];
nl = cfg(:,timecol(1:nlcount));
st = cfg(:,timecol(nlcount+1));
latency=cfg(:,timecol(nlcount+2));
et = st + latency;
for ix = 1:length(latency)
    if et(ix) > scheduletime
        et(ix)=mod(et(ix),scheduletime);
    end
end

scheduletime = schedule(1,1);
%-------------------------------------------------
% Load operand mapping
%-------------------------------------------------
op = getidfromname(operandname, s);

%--------------------------------------------------
% get the operation index
%--------------------------------------------------
same_ops_inst = find(op == sfg(:,1));
if isempty(same_ops_inst)
    error('Operand type not found');
end
same_ops_i = zeros(1,length(same_ops_inst));
for ik = 1:length(same_ops_inst)
    same_ops_i(ik) = sfg(same_ops_inst(ik),2);
end
index = find(number == same_ops_i);

if isempty(index)
    error('operand number mismatch');
end

op_i = same_ops_inst(index);

%-------------------------------------------------
delay_op = getidfromname('delay', s);
if (sfg(op_i,1) == delay_op)
    error('Delays cannot be moved')
end
%-------------------------------------------------


[innodes,outnodes]=getinoutnodes_op(sfg(op_i,:));
[ub]=getupperbound(schedule,op_i);
[lb]=getlowerbound(schedule,op_i);

if timedifference > ub
    error('Upper bound error');
end
if timedifference < lb
    error('Lower bound error');
end

inpmemtime=zeros(1,length(innodes));
outmemtime=zeros(1,length(outnodes));
backop_i=zeros(1,length(innodes));
backout_i=zeros(1,length(innodes));
forwardops = [];
forwardops_nl = [];

if~(isempty(innodes))
    for ix = 1:length(innodes)
        [backop_i(ix),backout_i(ix)]=get_opindices_backward(sfg,innodes(ix));
        if st(op_i) >= et(backop_i(ix))
            inpmemtime(ix) = st(op_i)-et(backop_i(ix)) + nl(op_i,ix)*scheduletime;
        else
            inpmemtime(ix) = st(op_i)-et(backop_i(ix)) + nl(op_i,ix)*scheduletime+scheduletime;
        end
    end
    if timedifference  >= 0
        newinpmemtime  = inpmemtime + abs(timedifference);
    else
        newinpmemtime  = inpmemtime - abs(timedifference);
    end
end

if ~(isempty(outnodes))
    for io = 1:length(outnodes)
        [forwardop_i,forwardin_i]=get_opindices_forward(sfg,outnodes(io));
        forwardops=[forwardops forwardop_i];
        forwardops_nl=[forwardops_nl forwardin_i];
    end
    
    for ii = 1:length(forwardops)
        if st(forwardops(ii)) >= et(op_i)
            outmemtime(ii) = st(forwardops(ii))-et(op_i)+nl(forwardops(ii),forwardops_nl(ii))*scheduletime;
        else
            outmemtime(ii) = st(forwardops(ii))-et(op_i)+nl(forwardops(ii),forwardops_nl(ii))*scheduletime+scheduletime;
        end
        
    end
    if timedifference  >= 0
        newoutmemtime  = outmemtime - abs(timedifference);
    else
        newoutmemtime  = outmemtime + abs(timedifference);
    end
end

%--------------------------------------------------------------------------
% Find the direction of movement and update the outmem and inpmem
% accordingly
%--------------------------------------------------------------------------
delta = timedifference;
quotient =fix(delta/scheduletime);
remainder = delta + abs(quotient)*scheduletime;
stime = st(op_i) + remainder;
if stime < 0
    st(op_i) = stime + scheduletime;
elseif stime > scheduletime
    st(op_i) = mod(stime,scheduletime);
else
    if latency(op_i) == 0
        st(op_i)=stime;
    else
        st(op_i)=mod(stime,scheduletime);
    end
end
% Update the number of laps carefully
% Present instr
if ~(isempty(innodes))
    inpmemtime_nl = fix(newinpmemtime./scheduletime);
    for ij = 1:length(backop_i)
        nl(op_i,ij)=inpmemtime_nl(ij);
    end
end

% Forward instr
if ~(isempty(outnodes))
    outmemtime_nl = fix(newoutmemtime./scheduletime);
    for ik = 1:length(forwardops)
        nl(forwardops(ik),forwardops_nl(ik))=outmemtime_nl(ik);
    end
end
%end
%--------------------------------------------------------------------------
%form newschedule
%--------------------------------------------------------------------------
newschedule = schedule;
newschedule(2:size_schedule(1),time_columns_index:(time_columns_index+nlcount-1))=nl;
newschedule(2:size_schedule(1),time_columns_index+nlcount)=st;
%--------------------------------------------------------------------------


