function errorlist = checknodes(sfg, verbose, opstruct)
% This function checks so that
% * outputs are not driven by more than one operand
% * there are no loose nodes
% 
% For a correct signal flow graph the result vector is empty

% Check input arguments
if nargin < 1
    error('Not enough input arguments');
end
if nargin < 2
    verbose = 1;
end

if nargin < 3
    opstruct = operandstructure;
end
[innodes, outnodes] = getinoutnodes(sfg, opstruct);

% Check that all outputs are not driven by more than one operand
id = find(~diff(outnodes));
e1 = outnodes(id);
e1(find(~diff(e1))) = [];
if verbose && ~isempty(e1)
    fprintf('ERROR! Nodes driven by more than one operand: %s\n', int2str(e1));
end

% Check that there are no loose nodes
outnodes(id) = [];
innodes(find(~diff(innodes))) = [];
e2 = [];
for i = 1:length(outnodes)
    if ~max(outnodes(i) == innodes)
        e2 = [e2, outnodes(i)];
    end
end
if verbose && ~isempty(e2)
    fprintf('ERROR! Unused output nodes: %s\n', int2str(e2));
end
e3 = [];
for i = 1:length(innodes)
    if ~max(innodes(i) == outnodes)
        e3 = [e3, innodes(i)];
    end
end
if verbose && ~isempty(e3)
    fprintf('ERROR! Unavailable input nodes: %s\n', int2str(e3));
end

errorlist = sort([e1, e2, e3]);
errorlist(find(~diff(errorlist))) = [];
