function memoryvariables = extractmemoryvariables(schedule)
% EXTRACTMEMORYVARIABLES Extract memory variables from a schedule

% Copyright 2004-2006
%                Electronics Systems, Dept of EE,
%                Linkoping University, SE-581 83 Linkoping
%                Sweden
%

% Load operand mapping
s = operandstructure;
out_op = getidfromname('out',s);
in_op = getidfromname('in',s);

scheduletime = schedule(1,1);
mv = scheduletime;
s=size(schedule);
for operand=2:s(1)
    
    % Out operations does not create any memory variables, skip them
    if schedule(operand,1) ~= out_op
        [~, outnodessource] = getinoutnodes_op(schedule(operand,:));
        [~, ub_vec] = getupperbound(schedule, operand - 1);
        
        starttime=mod(schedule(operand,s(2)-2)+schedule(operand,s(2)-1),scheduletime);
        sourceoperandnumber = schedule(operand,1:2);
        
        ports = length(unique(ub_vec(:,2)));

        % One memory variable for each outport
        for port=1:ports  
            idx=find(ub_vec(:,2)==port)';
            endtime = mod(starttime + max(ub_vec(idx,1)),scheduletime);
            consumeinfo=[];

            for consumeidx = idx
                consumeoperandnumber = schedule(ub_vec(consumeidx,3)+1,1:2);

                consumetime = mod(starttime + ub_vec(consumeidx,1),scheduletime);
                [innodes, ~] = getinoutnodes_op(schedule(ub_vec(consumeidx,3)+1,:));
                consumeport = find(innodes == outnodessource(port));

                for cp = consumeport
                    consumeinfo = [consumeinfo consumetime consumeoperandnumber cp];
                end
            end

            if ~isempty(consumeinfo)
                variableinfo = [starttime endtime sourceoperandnumber port consumeinfo];
                mv = addrow(mv, variableinfo);
            end
        end
    end
end



memoryvariables=mv;
