function sfgflat = flattensfg(sfg)
% This function flattens a signal flow graph.

% Initialize
operandmapping;
s = operandstructure;
nodelist = getnodelist(sfg,s);
node = max(nodelist) + 1;
sfgflat = [];
sfgsize = size(sfg);

% Target operations
constmult_op = getidfromname('constmult',s);
mult_op = getidfromname('mult',s);
add_op = getidfromname('add',s);
sub_op = getidfromname('sub',s);
negate_op = getidfromname('negate',s);

% Operations to be flattened
twoport_op = getidfromname('twoport',s);
threeport_op = getidfromname('threeport',s);
fourport_op = getidfromname('fourport',s);
constmac_op = getidfromname('constmac',s);
mac_op = getidfromname('mac',s);
butterfly2_op = getidfromname('butterfly2',s);

% Find start id's
addid = 1; subid = 1; cmultid = 1; invid = 1; multid = 1;
for operand = 1:sfgsize(1)
    id = sfg(operand, 2);
    switch sfg(operand, 1)
        case add_op
            if id >= addid
                addid = id + 1;
            end
        case sub_op
            if id >= subid
                subid = id + 1;
            end
        case constmult_op
            if id >= cmultid
                cmultid = id + 1;
            end
        case mult_op
            if id >= multid
                multid = id + 1;
            end
        case negate_op
            if id >= invid
                invid = id + 1;
            end
    end
end

% Loop over all operands
for operand = 1:sfgsize(1)
    op = sfg(operand, :);
    switch op(1)
        case twoport_op
            switch op(8)
                case adaptor_ser
                    sfgflat = addrow(sfgflat, [add_op, addid, op(3), op(4), node]);
                    sfgflat = addrow(sfgflat, [constmult_op, cmultid, node, node + 1, -op(7)]);
                    sfgflat = addrow(sfgflat, [add_op, addid + 1, node + 1, op(3), op(5)]);
                    sfgflat = addrow(sfgflat, [add_op, addid + 2, node, op(5), node + 2]);
                    sfgflat = addrow(sfgflat, [negate_op, invid, node + 2, op(6)]);
                    node = node + 3;
                    addid = addid + 3; cmultid = cmultid + 1; invid = invid + 1;
                case adaptor_par
                    sfgflat = addrow(sfgflat, [sub_op, subid, op(4), op(3), node]);
                    sfgflat = addrow(sfgflat, [constmult_op, cmultid, node, node + 1, -op(7)]);
                    sfgflat = addrow(sfgflat, [add_op, addid, node + 1, op(4), op(6)]);
                    sfgflat = addrow(sfgflat, [add_op, addid + 1, node, op(6), op(5)]);
                    node = node + 2;
                    addid = addid + 2; subid = subid + 1; cmultid = cmultid + 1;
                case adaptor_sym
                    sfgflat = addrow(sfgflat, [sub_op, subid, op(4), op(3), node]);
                    sfgflat = addrow(sfgflat, [constmult_op, cmultid, node, node + 1, op(7)]);
                    sfgflat = addrow(sfgflat, [add_op, addid, node + 1, op(3), op(6)]);
                    sfgflat = addrow(sfgflat, [add_op, addid + 1, node + 1, op(4), op(5)]);
                    node = node + 2;
                    addid = addid + 2; subid = subid + 1; cmultid = cmultid + 1;
            end
        case threeport_op, sfgflat = addrow(sfgflat, op); % <FIXME>
            % Innode1 Innode2 Innode3 Outnode1 Outnode2 Outnode3 Coeff1 Coeff2 Type
        case fourport_op, sfgflat = addrow(sfgflat, op); % <FIXME>
            % Innode1 Innode2 Innode3 Innode 4 Outnode1
            % Outnode2 Outnode3 Outnode4 Coeff1 Coeff2 Coeff3 Type
        case butterfly2_op
            sfgflat = addrow(sfgflat, [add_op, addid, op(3), op(4), op(5)]);
            sfgflat = addrow(sfgflat, [sub_op, subid, op(3), op(4), op(5)]);
            addid = addid + 1; subid = subid + 1;
        case constmac_op
            sfgflat = addrow(sfgflat, [constmult_op, cmultid, op(3), node, op(6)]);
            sfgflat = addrow(sfgflat, [add_op, addid, node, op(4), op(5)]);
            node = node + 1;
            addid = addid + 1; cmultid = cmultid + 1;
        case mac_op
            sfgflat = addrow(sfgflat, [mult_op, multid, op(3), op(4), node]);
            sfgflat = addrow(sfgflat, [add_op, addid, node, op(5), op(6)]);
            node = node + 1;
            addid = addid + 1; multid = multid + 1;
        otherwise, sfgflat = addrow(sfgflat, op);
    end
end

