function getTmin(sfg, style)
% This function prints the Tmin expression.
% 
% T_min = max{T_opi/N_i}
% where - T_opi is the latency of the operations in loop i
%       - N_i is the number of delay elements in loop i

latex = 0;
if (nargin == 2)
    latex = strcmpi(style,'latex');
end
[delayfree, loops, operands] = delayfreeloops(sfg);

if ~isempty(delayfree)
    error('The signal flow graph contain delay free loops');
end
numofloops = size(loops);
if ~numofloops(1)
    error('The signal flow graph does not contain any loops');
end

% Delete equal loops
delete_id = [];
for loop_no = 1:numofloops(1) - 1
    if isempty(delete_id) || isempty(find(loop_no == delete_id))
        for i = loop_no + 1:numofloops(1)
            if sum(operands(loop_no, :) == operands(i, :)) == length(operands(i, :))
                delete_id = [delete_id, i];
            end
        end
    end
end
loops(delete_id, :) = [];
operands(delete_id, :) = [];
numofloops = size(loops);

% Load operand mapping
s = operandstructure;
nooperands = length(s);
delay_id = getidfromname('delay',s);

fid = 1;
if latex 
    fprintf(fid, '\tT_{\\text{min}} = \\max\\left{');
else
    fprintf(fid, '\tT_min = max{\n');
end

for loop_no = 1:numofloops(1)
    opid = find(operands(loop_no, :));
    opid(opid == delay_id) = [];
    delay = operands(loop_no, delay_id);
    if ~latex
        fprintf(fid, '\t\t\t');
    end
    if delay > 1
        if latex
            fprintf(fid, '\\frac{');
        else 
            fprintf(fid, '( ');
        end
    end
    for op_no = 1:length(opid)
        op = opid(op_no);
        if nooperands >= op
            op_str = s(op).name;
            if latex
                op_str = sprintf('{\\text{%s}}', op_str);
            end
        else
            error('Unknown operand');
        end
        n = operands(loop_no, op);
        if n > 1
            if latex
                fprintf(fid, '%d', n);
            else
                fprintf(fid, '%d*', n);
            end
        end
        fprintf(fid, 'T_%s', op_str);
        if op_no < length(opid)
            fprintf(fid, ' + ');
        elseif delay > 1
            if latex
                fprintf(fid, '}{%d}', delay);
            else
                fprintf(fid, ' ) / %d', delay);
            end
        end
    end
    if loop_no < numofloops(1)
        if latex
            fprintf(fid, ',\\ ');
        else
            fprintf(fid, ',\n');
        end
    end
end
if latex
    fprintf(fid, '\\right}\n');
else
    fprintf(fid, ' }\n');
end