function printoperand2(operand, fid)

% Check number of input arguments
if nargin < 1
    error('Not enough input arguments');
end
if nargin > 2
    error('Too many input arguments');
end

% If not defined, set a file identifier
if nargin < 2
    fid = 1;
end

% Load operand mapping
operandmapping;

opstruct = operandstructure;
shift_op = getidfromname('shift',opstruct);
quant_op = getidfromname('quant',opstruct);
overflow_op = getidfromname('overflow',opstruct);

% Print the operand
d = 0; g = 1; s = 2;
argformat = opstruct(operand(1)).argformat;
op_str = sprintf('%-15s', opstruct(operand(1)).name);
switch operand(1)
    case shift_op
        switch operand(6)
            case shift_left, type_str = 'left';
            case shift_right, type_str = 'right';
            otherwise, error('Unknown shift type');
        end
    case quant_op
        switch operand(6)
            case quant_truncation, type_str = 'truncation';
            case quant_rounding, type_str = 'rounding';
            case quant_magnitudetruncation, type_str = 'magnitudetruncation';
            otherwise, error('Unknown quantization type');
        end
    case overflow_op
        switch operand(5)
            case overflow_twosc, type_str = 'twosc';
            case overflow_saturation, type_str = 'saturation';
            otherwise, error('Unknown overflow type');
        end
end

if opstruct(operand(1)).isadaptor
    switch operand(1 + length(argformat))
        case adaptor_ser, type_str = 'series';
        case adaptor_par, type_str = 'parallel';
        case adaptor_sym, type_str = 'symmetric';
        otherwise, error('Unknown adaptor type');
    end
end

numinout = opstruct(operand(1)).inout;

fprintf(fid, '%s', op_str);
for argid = 1:length(argformat)
    tab = 1;
    if argid == 1
        arg_str = 'id: ';
    elseif numinout(1) && (argid == 2)
        arg_str = 'in: ';
    elseif numinout(2) && (argid == 2 + numinout(1))
        arg_str = 'out: ';
    elseif (argformat(argid) == d) && (argid == 2 + sum(numinout))
        arg_str = 'bits: ';
    elseif (argformat(argid) == g) && (argid == 2 + sum(numinout))
        arg_str = 'coeff: ';
    elseif argformat(argid) == s
        arg_str = 'type: ';
    else
        arg_str = ', ';
        tab = 0;
    end
    if tab
        fprintf(fid, '\t');
    end
    if argformat(argid) == d
        fprintf(fid, '%s%d', arg_str, operand(argid + 1));
    elseif argformat(argid) == g
        fprintf(fid, '%s%0.3g', arg_str, operand(argid + 1));
    elseif argformat(argid) == s
        fprintf(fid, '%s%s', arg_str, type_str);
    end
end
fprintf(fid, '\n');
